==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-config/lxqt-config-input/lxqt-config-input_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Частота мерцания курсора:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Клавиатура&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Пищать при ошибке ввода с клавиатуры</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Повтор символа</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="79"/>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Длинная</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Задержка повтора:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="115"/>
        <location filename="../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Короткая</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Пауза между повтором:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Поле для проверки настроек клавиатуры</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <location filename="../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Включать NumLock при входе в систему</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Раскладка клавиатуры&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Раскладка</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Вариант</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>up</source>
        <translation>выше</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>down</source>
        <translation>ниже</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Модель клавиатуры:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Клавиши смены раскладки:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Внимание&lt;/span&gt;: если вы используете &lt;span style=&quot; font-weight:600;&quot;&gt;метод ввода&lt;/span&gt;, такой как IBus, uim, fcitx или gcin, настройки здесь &lt;span style=&quot; font-weight:600;&quot;&gt;могут не работать&lt;/span&gt;, поскольку они переопределятся этим методом ввода.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Мышь&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Движение</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Высокая</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Быстро</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Чувствительность:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Низкая</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Ускорение:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Медленно</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="116"/>
        <location filename="../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Интервал двойного щелчка:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Колёсико перематывает строк:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Для левшей (поменять функции левой и правой кнопок мыши)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Один клик для активации элементов</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="34"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Настройки клавиатуры и мыши</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="39"/>
        <source>Mouse</source>
        <translation>Мышь</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="44"/>
        <source>Cursor</source>
        <translation>Курсор</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="47"/>
        <source>Keyboard</source>
        <translation>Клавиатура</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="51"/>
        <source>Keyboard Layout</source>
        <translation>Раскладка клавиатура</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Выбрать раскладку клавиатуры</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Раскладка клавиатуры</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Вариант</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-input/lxqt-config-input_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../../../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Частота мерцания курсора:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Клавиатура&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Пищать при ошибке ввода с клавиатуры</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Повтор символа</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="79"/>
        <location filename="../../../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Длинная</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Задержка повтора:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="115"/>
        <location filename="../../../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Короткая</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Пауза между повтором:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Поле для проверки настроек клавиатуры</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="150"/>
        <location filename="../../../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Включать NumLock при входе в систему</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Раскладка клавиатуры&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Раскладка</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Вариант</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="77"/>
        <source>up</source>
        <translation>выше</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="84"/>
        <source>down</source>
        <translation>ниже</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Модель клавиатуры:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Клавиши смены раскладки:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Внимание&lt;/span&gt;: если вы используете &lt;span style=&quot; font-weight:600;&quot;&gt;метод ввода&lt;/span&gt;, такой как IBus, uim, fcitx или gcin, настройки здесь &lt;span style=&quot; font-weight:600;&quot;&gt;могут не работать&lt;/span&gt;, поскольку они переопределятся этим методом ввода.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../../../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Мышь&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Движение</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Высокая</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Быстро</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Чувствительность:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Низкая</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Ускорение:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Медленно</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="116"/>
        <location filename="../../../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Интервал двойного щелчка:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Колёсико перематывает строк:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Для левшей (поменять функции левой и правой кнопок мыши)</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Один клик для активации элементов</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="34"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Настройки клавиатуры и мыши</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="39"/>
        <source>Mouse</source>
        <translation>Мышь</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="44"/>
        <source>Cursor</source>
        <translation>Курсор</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="47"/>
        <source>Keyboard</source>
        <translation>Клавиатура</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="51"/>
        <source>Keyboard Layout</source>
        <translation>Раскладка клавиатура</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Выбрать раскладку клавиатуры</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Раскладка клавиатуры</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Вариант</translation>
    </message>
</context>
</TS>
